@@ -1,24 +1,28 @@
 # Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
+from __future__ import annotations
 
 import logging
-from typing import Dict
+from typing import TYPE_CHECKING, TypeVar
 
 import attr
 
-from openlineage.client.run import RunEvent
 from openlineage.client.serde import Serde
 from openlineage.client.transport.transport import Config, Transport
 from openlineage.client.utils import get_only_specified_fields
 
+if TYPE_CHECKING:
+    from openlineage.client.run import RunEvent
 log = logging.getLogger(__name__)
 
+_T = TypeVar("_T", bound="KafkaConfig")
+
 
 @attr.s
 class KafkaConfig(Config):
     # Kafka producer config
     # https://docs.confluent.io/platform/current/clients/confluent-kafka-python/html/index.html#kafka-client-configuration
-    config: Dict[str, str] = attr.ib()
+    config: dict[str, str] = attr.ib()
 
     # Topic on which we should send messages
     topic: str = attr.ib()
@@ -28,11 +32,13 @@ class KafkaConfig(Config):
     flush: bool = attr.ib(default=True)
 
     @classmethod
-    def from_dict(cls, params: dict):
-        if 'config' not in params:
-            raise RuntimeError("kafka `config` not passed to KafkaConfig")
-        if not isinstance(params['config'], dict):
-            raise RuntimeError("`config` passed to KafkaConfig must be dict")
+    def from_dict(cls: type[_T], params: dict[str, str]) -> _T:
+        if "config" not in params:
+            msg = "kafka `config` not passed to KafkaConfig"
+            raise RuntimeError(msg)
+        if not isinstance(params["config"], dict):
+            msg = "`config` passed to KafkaConfig must be dict"
+            raise RuntimeError(msg)  # noqa: TRY004
         return cls(**get_only_specified_fields(cls, params))
 
 
@@ -41,20 +47,23 @@ class KafkaTransport(Transport):
     kind = "kafka"
     config = KafkaConfig
 
-    def __init__(self, config: KafkaConfig):
+    def __init__(self, config: KafkaConfig) -> None:
         try:
             import confluent_kafka as kafka
+
             self.producer = kafka.Producer(config.config)
             self.topic = config.topic
             self.flush = config.flush
         except ModuleNotFoundError:
-            log.error("OpenLineage client did not found confluent-kafka module. "
-                      "Installing it is required for KafkaTransport to work. "
-                      "You can also get it via `pip install openlineage-python[kafka]`")
+            log.exception(
+                "OpenLineage client did not found confluent-kafka module. "
+                "Installing it is required for KafkaTransport to work. "
+                "You can also get it via `pip install openlineage-python[kafka]`",
+            )
             raise
-        log.debug(f"Constructing openlineage client to send events to topic {config.topic}")
+        log.debug("Constructing openlineage client to send events to topic %s", config.topic)
 
-    def emit(self, event: RunEvent):
-        self.producer.produce(topic=self.topic, value=Serde.to_json(event).encode('utf-8'))
+    def emit(self, event: RunEvent) -> None:
+        self.producer.produce(topic=self.topic, value=Serde.to_json(event).encode("utf-8"))
         if self.flush:
             self.producer.flush(timeout=5)
