@@ -1,28 +1,35 @@
 # Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
+from __future__ import annotations
 
 import datetime
 import uuid
-from unittest.mock import patch
+from typing import TYPE_CHECKING
+
+from requests import Session
 
 from openlineage.client import OpenLineageClient
 from openlineage.client.run import Job, Run, RunEvent, RunState
 from openlineage.client.serde import Serde
 from openlineage.client.transport.http import HttpConfig, HttpTransport
-from requests import Session
+
+if TYPE_CHECKING:
+    from pytest_mock import MockerFixture
 
 
-def test_http_loads_full_config():
-    config = HttpConfig.from_dict({
-        "type": "http",
-        "url": "http://backend:5000",
-        "endpoint": "api/v1/lineage",
-        "verify": False,
-        "auth": {
-            "type": "api_key",
-            "api_key": "1500100900"
+def test_http_loads_full_config() -> None:
+    config = HttpConfig.from_dict(
+        {
+            "type": "http",
+            "url": "http://backend:5000",
+            "endpoint": "api/v1/lineage",
+            "verify": False,
+            "auth": {
+                "type": "api_key",
+                "api_key": "1500100900",
+            },
         },
-    })
+    )
 
     assert config.url == "http://backend:5000"
     assert config.endpoint == "api/v1/lineage"
@@ -32,25 +39,29 @@ def test_http_loads_full_config():
     assert config.adapter is None
 
 
-def test_http_loads_minimal_config():
-    config = HttpConfig.from_dict({
-        "type": "http",
-        "url": "http://backend:5000/api/v1/lineage"
-    })
+def test_http_loads_minimal_config() -> None:
+    config = HttpConfig.from_dict(
+        {
+            "type": "http",
+            "url": "http://backend:5000/api/v1/lineage",
+        },
+    )
     assert config.url == "http://backend:5000/api/v1/lineage"
     assert config.verify is True
-    assert not hasattr(config.auth, 'api_key')
+    assert not hasattr(config.auth, "api_key")
     assert isinstance(config.session, Session)
     assert config.adapter is None
 
 
-@patch("requests.Session")
-def test_client_with_http_transport_emits(session):
-    config = HttpConfig.from_dict({
-        "type": "http",
-        "url": "http://backend:5000",
-        "session": session
-    })
+def test_client_with_http_transport_emits(mocker: MockerFixture) -> None:
+    session = mocker.patch("requests.Session")
+    config = HttpConfig.from_dict(
+        {
+            "type": "http",
+            "url": "http://backend:5000",
+            "session": session,
+        },
+    )
     transport = HttpTransport(config)
 
     client = OpenLineageClient(transport=transport)
@@ -67,18 +78,19 @@ def test_client_with_http_transport_emits(session):
         "http://backend:5000/api/v1/lineage",
         Serde.to_json(event),
         timeout=5.0,
-        verify=True
+        verify=True,
     )
 
 
-@patch("requests.Session")
-def test_client_with_http_transport_emits_custom_endpoint(session):
-    config = HttpConfig.from_dict({
-        "type": "http",
-        "url": "http://backend:5000",
-        "endpoint": "custom/lineage",
-        "session": session
-    })
+def test_client_with_http_transport_emits_custom_endpoint(mocker: MockerFixture) -> None:
+    config = HttpConfig.from_dict(
+        {
+            "type": "http",
+            "url": "http://backend:5000",
+            "endpoint": "custom/lineage",
+            "session": mocker.patch("requests.Session"),
+        },
+    )
     transport = HttpTransport(config)
 
     client = OpenLineageClient(transport=transport)
@@ -95,5 +107,5 @@ def test_client_with_http_transport_emits_custom_endpoint(session):
         "http://backend:5000/custom/lineage",
         Serde.to_json(event),
         timeout=5.0,
-        verify=True
+        verify=True,
     )
